***************
Iterator Ranges
***************


.. doxygenfunction:: Dune::incidentElements

.. doxygenfunction:: Dune::incidentFacets

.. doxygenfunction:: Dune::incidentVertices

.. doxygenfunction:: Dune::interfaceElements

.. doxygenfunction:: Dune::interfaceVertices

.. doxygenfunction:: Dune::incidentInterfaceVertices

.. doxygenfunction:: Dune::incidentInterfaceElements
